@@ -1,4 +1,4 @@
-(set-background "meditate.png")
+(set-background "level1.png")
 (set-skin "skin.png")
 (set-bonus-time 80000)
 (load "../utils.scm")
