@@ -1,4 +1,4 @@
-(set-background "3d-gnu.png")
+(set-background "level2.png")
 (set-skin "skin.png")
 (set-bonus-time 80000)
 (load "../utils.scm")
