@@ -1,4 +1,4 @@
-(set-background "dale_mellor.png")
+(set-background "level4.png")
 (set-skin "skin.png")
 (set-bonus-time 80000)
 (load "../utils.scm")
