@@ -62,22 +62,22 @@ Game::init ()
   balls_y = 427;
   ball_padding = 5;
 
-  level_label_font_face = "FreeSans";
+  level_label_font_face = "kochi-gothic";
   level_label_font_size = 24;
   level_label_font_color.r = 255;
   level_label_font_color.g = 255;
   level_label_font_color.b = 255;
-  level_font_face = "FreeSans";
+  level_font_face = "kochi-gothic";
   level_font_size = 24;
   level_font_color.r = 255;
   level_font_color.g = 255;
   level_font_color.b = 255;
-  score_label_font_face = "FreeSans";
+  score_label_font_face = "kochi-gothic";
   score_label_font_size = 24;
   score_label_font_color.r = 255;
   score_label_font_color.g = 255;
   score_label_font_color.b = 255;
-  score_font_face = "FreeSans";
+  score_font_face = "kochi-gothic";
   score_font_size = 24;
   score_font_color.r = 255;
   score_font_color.g = 255;
@@ -92,12 +92,12 @@ Game::init ()
   gameover_score_label_y = 10;
   gameover_score_x = 546;
   gameover_score_y = 39;
-  gameover_score_font_face = "FreeSans";
+  gameover_score_font_face = "kochi-gothic";
   gameover_score_font_size = 24;
   gameover_score_font_color.b = 255;
   gameover_score_font_color.r = 255;
   gameover_score_font_color.g = 255;
-  gameover_score_label_font_face = "FreeSans";
+  gameover_score_label_font_face = "kochi-gothic";
   gameover_score_label_font_size = 24;
   gameover_score_label_font_color.r = 255;
   gameover_score_label_font_color.g = 255;
@@ -316,13 +316,13 @@ Game::draw (SDL_Surface * dest)
       drawBox (buffer, 120, 200, 250, 40,
 	       SDL_MapRGB (buffer->format, 64, 64, 64),
 	       SDL_MapRGB (buffer->format, 0, 0, 0));
-      font_manager->drawString ("FreeSans", 16, "Get Ready", 150, 205, buffer, readycolor);
+      font_manager->drawString ("kochi-gothic", 16, "Get Ready", 150, 205, buffer, readycolor);
       if (timeTilReady < 1800)
-	font_manager->drawString ("FreeSans", 16, ".", 294, 200, buffer, readycolor);
+	font_manager->drawString ("kochi-gothic", 16, ".", 294, 200, buffer, readycolor);
       if (timeTilReady < 1200)
-	font_manager->drawString ("FreeSans", 16, ".", 310, 200, buffer, readycolor);
+	font_manager->drawString ("kochi-gothic", 16, ".", 310, 200, buffer, readycolor);
       if (timeTilReady < 600)
-	font_manager->drawString ("FreeSans", 16, ".", 326, 200, buffer, readycolor);
+	font_manager->drawString ("kochi-gothic", 16, ".", 326, 200, buffer, readycolor);
     }
 
   if (m_paused)
@@ -330,7 +330,7 @@ Game::draw (SDL_Surface * dest)
       drawBox (buffer, 180, 200, 130, 40,
 	       SDL_MapRGB (buffer->format, 64, 64, 64),
 	       SDL_MapRGB (buffer->format, 0, 0, 0));
-      font_manager->drawString ("FreeSans", 16, "Paused", 190, 205, buffer, readycolor);
+      font_manager->drawString ("kochi-gothic", 16, "Paused", 190, 205, buffer, readycolor);
     }
 
   SDL_Rect d = { field_x, field_y, 0, 0 };
@@ -392,8 +392,8 @@ Game::draw (SDL_Surface * dest)
   for (int i = 0; i < levelBuffer; i++)
     strLevel += ' ';
   strLevel += ssLevel.str ();
-  font_manager->drawString ("FreeSans", level_label_font_size, "Level: ", level_label_x, level_label_y, dest, level_label_font_color);
-  font_manager->drawString ("FreeSans", level_font_size, strLevel.c_str (), level_x, level_y, dest, level_font_color);
+  font_manager->drawString ("kochi-gothic", level_label_font_size, "Level: ", level_label_x, level_label_y, dest, level_label_font_color);
+  font_manager->drawString ("kochi-gothic", level_font_size, strLevel.c_str (), level_x, level_y, dest, level_font_color);
 
   // draw the score
   stringstream ssScore (stringstream::in | stringstream::out);
@@ -405,8 +405,8 @@ Game::draw (SDL_Surface * dest)
   for (int i = 0; i < scoreBuffer; i++)
     strScore += ' ';
   strScore += ssScore.str ();
-  font_manager->drawString ("FreeSans", score_label_font_size, "Score: ", score_label_x, score_label_y, dest, score_label_font_color);
-  font_manager->drawString ("FreeSans", score_font_size, strScore.c_str (), score_x, score_y, dest, score_font_color);
+  font_manager->drawString ("kochi-gothic", score_label_font_size, "Score: ", score_label_x, score_label_y, dest, score_label_font_color);
+  font_manager->drawString ("kochi-gothic", score_font_size, strScore.c_str (), score_x, score_y, dest, score_font_color);
 }
 
 void
