@@ -21,6 +21,11 @@
 #include <string>
 using namespace std;
 
+#include "config.h"
+#include "gettext.h"
+
+#define _(str) gettext (str)
+
 #define FONT_INACTIVE 0
 #define FONT_ACTIVE 1
 #define FONT_WHITE 2
@@ -45,23 +50,7 @@ using namespace std;
 #define OPTIONS_SOUNDS 1
 #define OPTIONS_BACK 2
 
-#ifndef PREFIX
-#define SINGLEDIR
-#define PREFIX "."
-#define IMAGEPATH string(PREFIX)+"/images"
-#define SOUNDPATH string(PREFIX)+"/sounds"
-#define LEVELPATH string(PREFIX)+"/levels"
-#endif
-
-#ifndef IMAGEPATH
-#define IMAGEPATH string(PREFIX)+"/share/ballandpaddle/images"
-#endif
-
-#ifndef SOUNDPATH
-#define SOUNDPATH string(PREFIX)+"/share/ballandpaddle/sounds"
-#endif
-
-#ifndef LEVELPATH
-#define LEVELPATH string(PREFIX)+"/share/ballandpaddle/levels"
-#endif
+#define IMAGEPATH string(BAP_DATADIR)+"/images"
+#define SOUNDPATH string(BAP_DATADIR)+"/sounds"
+#define LEVELPATH string(BAP_DATADIR)+"/levels"
 
