@@ -1,7 +1,7 @@
 /*
  *  Ball And Paddle
  *
- *  Copyright (C) 2007 by Eric Hutchins
+ *  Copyright (C) 2007, 2008 by Eric Hutchins
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -26,19 +26,19 @@ using namespace std;
 #include "SDL.h"
 #include "SDL_image.h"
 
+#include "poweruptype.h"
 #include "globals.h"
 
 class PowerUp
 {
   double x;
   double y;
-  int width;
-  int height;
-  int type;
+  SDL_Surface *imgPowerUps;
+  PowerUpType * type;
 public:
-    PowerUp (double x, double y, int width, int height, int type);
+    PowerUp (double x, double y, PowerUpType * type, SDL_Surface * imgPowerUps);
    ~PowerUp ();
-  void draw (SDL_Surface * sprite, SDL_Surface * dest);
+  void draw (SDL_Surface * dest);
   void update (int time);
   double getX ()
   {
@@ -50,13 +50,17 @@ public:
   }
   int getWidth ()
   {
-    return width;
+    return type->get_width ();
   }
   int getHeight ()
   {
-    return height;
+    return type->get_height ();
   }
-  int getType ()
+  string get_script ()
+  {
+    return type->get_script ();
+  }
+  PowerUpType * getType ()
   {
     return type;
   }
