@@ -1,7 +1,7 @@
 /*
  *  Ball And Paddle
  *
- *  Copyright (C) 2007 by Eric Hutchins
+ *  Copyright (C) 2007, 2008 by Eric Hutchins
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -37,7 +37,7 @@ private:
   static Splash m_instance;
   SDL_Surface *image;
   int time;
-  int currentTime;
+  long last_time;
 public:
   static Splash *instance ()
   {
@@ -47,13 +47,13 @@ public:
   void cleanup ();
   void pause ();
   void resume ();
-  void handleEvents (GameStateManager * gameStateManager);
-  void draw (GameStateManager * gameStateManager);
-  void update (GameStateManager * gameStateManager);
+  void handleEvents ();
+  void draw (SDL_Surface *dest);
+  void update ();
   void start ();
   bool done ()
   {
-    return currentTime >= time;
+    return SDL_GetTicks () - last_time >= time;
   }
   bool getTransitioning ()
   {
